Module utils

Module utils 

Enums

ChainDataIndex
Represents the key for each unique value of the chain data stored in the db
SnapStateIndex
Represents the key for each unique value of the snap state stored in the db