pub type MigrationFn = fn(backend: &dyn StorageBackend) -> Result<(), StoreError>;Expand description
A migration function that upgrades the database schema by one version.
Receives a reference to the storage backend so it can read/write data as needed for the migration.