Structs
- Account
Proof - Account
Updates List - Collection of account state changes from block execution.
- Ancestor
Iterator - Storage
Slot Proof - Store
- Main storage interface for the ethrex client.
- Store
Config - Tunable configuration for
Store::new_with_configand related constructors. - Store
Metadata - Update
Batch - Batch of updates to apply to the store atomically.
Enums
- Engine
Type - Storage backend type selection.
Constants
- DEFAULT_
ROCKSDB_ BLOCK_ CACHE_ SIZE_ BYTES - Default size in bytes of the RocksDB shared block cache: 12 GiB.
- MAX_
WITNESSES - Maximum number of execution witnesses to keep in the database
Functions
- has_
valid_ db - Checks whether a valid (or migratable) database exists at the given path
by looking for a metadata.json file with a schema version between 1 and
STORE_SCHEMA_VERSION(inclusive). - hash_
address - hash_
key - hash_
key_ fixed - read_
chain_ id_ from_ db - Reads the chain ID from an existing database without performing a full
store initialization. Returns
Noneif the database doesn’t exist or the chain config can’t be read. Always returnsNonewhen compiled without therocksdbfeature. - receipt_
key - Builds a fixed-width RECEIPTS key: block_hash (32B) || index (8B BE).
- tx_
locations_ merge - Merge function for the
TRANSACTION_LOCATIONScolumn family.
Type Aliases
- Storage
Trie Nodes - Storage trie nodes grouped by account address hash.
- Storage
Updates - Storage trie updates grouped by account address hash.