pub struct BackendTrieDB { /* private fields */ }Expand description
TrieDB implementation that holds a pre-acquired read view for the entire trie traversal, avoiding per-node-lookup allocation and lock acquisition.
Implementations
Sourceimpl BackendTrieDB
impl BackendTrieDB
Sourcepub fn new_for_accounts(
db: Arc<dyn StorageBackend>,
last_written: Vec<u8>,
) -> Result<Self, StoreError>
pub fn new_for_accounts( db: Arc<dyn StorageBackend>, last_written: Vec<u8>, ) -> Result<Self, StoreError>
Create a new BackendTrieDB for the account trie
Sourcepub fn new_for_accounts_with_view(
db: Arc<dyn StorageBackend>,
read_view: Arc<dyn StorageReadView>,
last_written: Vec<u8>,
) -> Result<Self, StoreError>
pub fn new_for_accounts_with_view( db: Arc<dyn StorageBackend>, read_view: Arc<dyn StorageReadView>, last_written: Vec<u8>, ) -> Result<Self, StoreError>
Create a new BackendTrieDB for the account trie with a shared read view
Sourcepub fn new_for_storages(
db: Arc<dyn StorageBackend>,
last_written: Vec<u8>,
) -> Result<Self, StoreError>
pub fn new_for_storages( db: Arc<dyn StorageBackend>, last_written: Vec<u8>, ) -> Result<Self, StoreError>
Create a new BackendTrieDB for the storage tries
Sourcepub fn new_for_storages_with_view(
db: Arc<dyn StorageBackend>,
read_view: Arc<dyn StorageReadView>,
last_written: Vec<u8>,
) -> Result<Self, StoreError>
pub fn new_for_storages_with_view( db: Arc<dyn StorageBackend>, read_view: Arc<dyn StorageReadView>, last_written: Vec<u8>, ) -> Result<Self, StoreError>
Create a new BackendTrieDB for the storage tries with a shared read view
Sourcepub fn new_for_account_storage(
db: Arc<dyn StorageBackend>,
address_prefix: H256,
last_written: Vec<u8>,
) -> Result<Self, StoreError>
pub fn new_for_account_storage( db: Arc<dyn StorageBackend>, address_prefix: H256, last_written: Vec<u8>, ) -> Result<Self, StoreError>
Create a new BackendTrieDB for a specific storage trie
Sourcepub fn new_for_account_storage_with_view(
db: Arc<dyn StorageBackend>,
read_view: Arc<dyn StorageReadView>,
address_prefix: H256,
last_written: Vec<u8>,
) -> Result<Self, StoreError>
pub fn new_for_account_storage_with_view( db: Arc<dyn StorageBackend>, read_view: Arc<dyn StorageReadView>, address_prefix: H256, last_written: Vec<u8>, ) -> Result<Self, StoreError>
Create a new BackendTrieDB for a specific storage trie with a shared read view